@@ -228,9 +228,8 @@ static void addressbook_foldersel_create( void )
 
 	gtk_widget_show_all( window );
 
-	stock_pixbuf_gdk( window, STOCK_PIXMAP_BOOK, &bookXpm);
-	stock_pixbuf_gdk( window, STOCK_PIXMAP_DIR_OPEN,
-			  &folderXpm);
+	stock_pixbuf_gdk(STOCK_PIXMAP_BOOK, &bookXpm);
+	stock_pixbuf_gdk(STOCK_PIXMAP_DIR_OPEN, &folderXpm);
 }
 
 static void addressbook_foldersel_load_folder( GtkCMCTreeNode *parentNode, ItemFolder *parentFolder,
