@@ -784,7 +784,6 @@ gchar *conv_codeset_strdup(const gchar *inbuf,
 	if (conv_func != conv_noconv) {
 		len = (strlen(inbuf) + 1) * 3;
 		buf = g_malloc(len);
-		if (!buf) return NULL;
 
 		if (conv_func(buf, len, inbuf) == 0 || !strict_mode)
 			return g_realloc(buf, strlen(buf) + 1);
@@ -1698,7 +1697,7 @@ void conv_encode_header_full(gchar *dest, gint len, const gchar *src,
 						*dest = '\0';
 						return;
 					} else {
-						g_warning("conv_encode_header(): code conversion failed");
+						g_warning("conv_encode_header_full(): code conversion failed");
 						conv_unreadable_8bit(part_str);
 						out_str = g_strdup(part_str);
 					}
@@ -1731,7 +1730,7 @@ void conv_encode_header_full(gchar *dest, gint len, const gchar *src,
 				out_str = conv_codeset_strdup
 					(part_str, cur_encoding, out_encoding);
 				if (!out_str) {
-					g_warning("conv_encode_header(): code conversion failed");
+					g_warning("conv_encode_header_full(): code conversion failed");
 					conv_unreadable_8bit(part_str);
 					out_str = g_strdup(part_str);
 				}
