@@ -134,6 +134,8 @@
 
 #define BUFFSIZE			8192
 
+#define RFC822_DATE_BUFFSIZE	128
+
 #ifndef MAXPATHLEN
 #  define MAXPATHLEN			4095
 #endif
@@ -170,6 +172,10 @@
 
 #define DEFAULT_PIXMAP_THEME	"INTERNAL_DEFAULT"
 #define PIXMAP_THEME_DIR		"themes"
+#ifdef HAVE_SVG
+#define MIN_PPI 96
+#define MAX_PPI 300
+#endif
 
 #define AVATAR_NONE	0
 #define AVATAR_XFACE	1
