@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2015 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2017 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,6 +48,9 @@
 #  include <netinet/in.h>
 #  include <arpa/inet.h>
 #  include <resolv.h>
+#  ifndef _PATH_RESCONF
+#    define _PATH_RESCONF "/etc/resolv.conf"
+#  endif
 #  include <netdb.h>
 #endif /* G_OS_WIN32 */
 #include <unistd.h>
@@ -221,7 +223,7 @@ void refresh_resolvers(void)
 	 * know if it'd work on BSDs.
 	 * Why doesn't the glibc do it by itself?
 	 */
-	if (g_stat("/etc/resolv.conf", &s) == 0) {
+	if (g_stat(_PATH_RESCONF, &s) == 0) {
 		if (s.st_mtime > resolv_conf_changed) {
 			resolv_conf_changed = s.st_mtime;
 			res_init();
@@ -720,7 +722,7 @@ static gboolean sock_connect_async_cb(GIOChannel *source,
 	g_io_channel_unref(source);
 
 	len = sizeof(val);
-	if (getsockopt(fd, SOL_SOCKET, SO_ERROR, &val, &len) < 0) {
+	if (getsockopt(fd, SOL_SOCKET, SO_ERROR, (void*)&val, &len) < 0) {
 		perror("getsockopt");
 		close(fd);
 		sock_connect_address_list_async(conn_data);
@@ -1422,8 +1424,7 @@ static gint fd_recv(gint fd, gchar *buf, gint len, gint flags)
 
 gint fd_gets(gint fd, gchar *buf, gint len)
 {
-	gchar *newline, *bp = buf;
-	gint n;
+	gchar *bp = buf;
 
 	if (--len < 1)
 		return -1;
@@ -1452,6 +1453,8 @@ Single-byte send() and recv().
 		len--;
 	} while (0 < len);
 #else /*!G_OS_WIN32*/
+	gchar *newline;
+	gint n;
 	do {
 		if ((n = fd_recv(fd, bp, len, MSG_PEEK)) <= 0)
 			return -1;
