@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2014 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  * The code of the g_utf8_substring function below is owned by
  * Matthias Clasen <matthiasc@src.gnome.org>/<mclasen@redhat.com>
  * and is got from GLIB 2.30
- *
  */
 
 #ifndef __UTILS_H__
@@ -432,8 +431,6 @@ const gchar *w32_get_cert_file		(void);
 #endif
 /* file / directory handling */
 off_t get_file_size		(const gchar	*file);
-off_t get_file_size_as_crlf	(const gchar	*file);
-
 time_t get_file_mtime		(const gchar *file);
 
 gboolean file_exist		(const gchar	*file,
@@ -505,7 +502,8 @@ char *fgets_crlf(char *buf, int size, FILE *stream);
 
 /* process execution */
 gint execute_command_line	(const gchar	*cmdline,
-				 gboolean	 async);
+				 gboolean	 async,
+				 const gchar	*working_directory);
 gchar *get_command_output	(const gchar	*cmdline);
 
 /* open URI with external browser */
@@ -519,6 +517,8 @@ time_t tzoffset_sec		(time_t		*now);
 gchar *tzoffset			(time_t		*now);
 void get_rfc822_date		(gchar		*buf,
 				 gint		 len);
+void get_rfc822_date_hide_tz	(gchar		*buf,
+				 gint		 len);
 
 size_t fast_strftime		(gchar 			*buf, 
 				 gint 			 buflen, 
@@ -543,7 +543,6 @@ const gchar * line_has_quote_char	(const gchar *str,
 
 gint g_int_compare	(gconstpointer a, gconstpointer b);
 
-gchar *generate_msgid		(gchar *buf, gint len, gchar *user_addr);
 gchar *generate_mime_boundary	(const gchar *prefix);
 
 gint quote_cmd_argument(gchar * result, guint size,
@@ -606,6 +605,8 @@ gchar   *g_utf8_substring         (const gchar *p,
                                    glong        end_pos) G_GNUC_MALLOC;
 #endif
 
+gboolean get_random_bytes(void *buf, size_t count);
+
 #ifdef __cplusplus
 }
 #endif
