@@ -369,7 +369,7 @@ static void crash_debug(unsigned long crash_pid,
 			perror("dup");
 		close(choutput[0]);
 		if (-1 == execvp("gdb", argp)) 
-			g_print("error execvp\n");
+			perror("execvp");
 	} else {
 		char buf[100];
 		int r;
@@ -541,12 +541,13 @@ static void crash_handler(int sig)
 		args[4] = NULL;
 
 		if (chdir(claws_get_startup_dir()) != 0)
-			perror("chdir");
+			FILE_OP_ERROR(claws_get_startup_dir(), "chdir");
 		if (setgid(getgid()) != 0)
 			perror("setgid");
 		if (setuid(getuid()) != 0 )
 			perror("setuid");
 		execvp(argv0, args);
+		perror("execvp");
 	} else {
 		waitpid(pid, NULL, 0);
 		crash_cleanup_exit();
