@@ -510,15 +510,15 @@ static gboolean filteringaction_apply(FilteringAction * action, MsgInfo * info)
 					path = action->destination;
 				start_address_completion(path);
 
-				address_list = address_list_append(address_list, header->body);
+				address_list = g_slist_append(address_list, header->body);
 				for (walk = address_list; walk != NULL; walk = walk->next) {
 					gchar *stripped_addr = g_strdup(walk->data);
 					extract_address(stripped_addr);
 
 					if (complete_matches_found(walk->data) == 0) {
 						gchar *name = procheader_get_fromname(walk->data);
-						debug_print("adding address '%s' to addressbook '%s'\n",
-								stripped_addr, action->destination);
+						debug_print("adding '%s <%s>' to addressbook '%s'\n",
+								name, stripped_addr, action->destination);
 #ifndef USE_ALT_ADDRBOOK
 						if (!addrbook_add_contact(abf, folder, name, stripped_addr, NULL)) {
 #else
@@ -872,7 +872,7 @@ gboolean filter_message_by_msginfo(GSList *flist, MsgInfo *info, PrefsAccount* a
 
 	if (prefs_common.enable_filtering_debug) {
 		gchar *tmp = _("undetermined");
-#ifndef G_OS_WIN32
+
 		switch (context) {
 		case FILTERING_INCORPORATION:
 			tmp = _("incorporation");
@@ -898,9 +898,7 @@ gboolean filter_message_by_msginfo(GSList *flist, MsgInfo *info, PrefsAccount* a
 			debug_filtering_session = FALSE;
 			break;
 		}
-#else
-		debug_filtering_session = FALSE;
-#endif
+
 		if (debug_filtering_session) {
 			gchar *file = procmsg_get_message_file_path(info);
 			gchar *spc = g_strnfill(LOG_TIME_LEN + 1, ' ');
