@@ -116,7 +116,7 @@ gint folderutils_delete_duplicates(FolderItem *item,
 
 	debug_print("done.\n");
 
-	return dups;	
+	return dups;
 }
 
 void folderutils_mark_all_read(FolderItem *item)
@@ -132,7 +132,7 @@ void folderutils_mark_all_read(FolderItem *item)
 	if (mainwin && mainwin->summaryview &&
 	    mainwin->summaryview->folder_item == item) {
 		debug_print("folder opened, using summary\n");
-		summary_mark_all_read(mainwin->summaryview);
+		summary_mark_all_read(mainwin->summaryview, FALSE);
 	} else {
 		msglist = folder_item_get_msg_list(item);
 		debug_print("got msglist %p\n", msglist);
@@ -159,6 +159,46 @@ void folderutils_mark_all_read(FolderItem *item)
 	folder_item_update_thaw();
 }
 
+void folderutils_mark_all_unread(FolderItem *item)
+{
+	MsgInfoList *msglist, *cur;
+	MainWindow *mainwin = mainwindow_get_mainwindow();
+	int i = 0, m = 0;
+	debug_print("marking all unread in item %s\n", (item==NULL)?"NULL":item->name);
+	cm_return_if_fail(item != NULL);
+
+
+	folder_item_update_freeze();
+	if (mainwin && mainwin->summaryview &&
+	    mainwin->summaryview->folder_item == item) {
+		debug_print("folder opened, using summary\n");
+		summary_mark_all_unread(mainwin->summaryview, FALSE);
+	} else {
+		msglist = folder_item_get_msg_list(item);
+		debug_print("got msglist %p\n", msglist);
+		if (msglist == NULL) {
+			folder_item_update_thaw();
+			return;
+		}
+		folder_item_set_batch(item, TRUE);
+		for (cur = msglist; cur != NULL; cur = g_slist_next(cur)) {
+			MsgInfo *msginfo = cur->data;
+
+			if (!(msginfo->flags.perm_flags & MSG_UNREAD)) {
+				procmsg_msginfo_set_flags(msginfo, MSG_UNREAD, 0);
+				m++;
+			}
+			i++;
+			procmsg_msginfo_free(&msginfo);
+		}
+		folder_item_set_batch(item, FALSE);
+		folder_item_close(item);
+		debug_print("marked %d messages out of %d as unread\n", m, i);
+		g_slist_free(msglist);
+	}
+	folder_item_update_thaw();
+}
+
 void folderutils_mark_all_read_recursive(FolderItem *item)
 {
 	GNode *node;
@@ -182,3 +222,27 @@ void folderutils_mark_all_read_recursive(FolderItem *item)
 		}
 	}
 }
+
+void folderutils_mark_all_unread_recursive(FolderItem *item)
+{
+	GNode *node;
+
+	cm_return_if_fail(item != NULL);
+
+	folderutils_mark_all_unread(item);
+
+	cm_return_if_fail(item->folder != NULL);
+	cm_return_if_fail(item->folder->node != NULL);
+
+	node = item->folder->node;
+	node = g_node_find(node, G_PRE_ORDER, G_TRAVERSE_ALL, item);
+	node = node->children;
+
+	while (node != NULL) {
+		if (node->data != NULL) {
+			FolderItem *sub_item = (FolderItem *) node->data;
+			node = node->next;
+			folderutils_mark_all_unread_recursive(sub_item);
+		}
+	}
+}
