@@ -3,7 +3,7 @@ static char *TEAM_LIST[] = {
 "Tristan Chabredier <wwp@claws-mail.org>",
 "Andrej Kacian <andrej@kacian.sk>",
 "Darko Koruga <darko@users.sf.net>",
-"Charles Lehner <charles@claws-mail.org",
+"Charles Lehner <charles@claws-mail.org>",
 "Colin Leroy <colin@colino.net>",
 "Paul Mangan <paul@claws-mail.org>",
 "Ricardo Mones Lastra <ricardo@mones.org>",
@@ -34,24 +34,28 @@ NULL
 };
 
 static char *TRANS_TEAM_LIST[] = {
-"[bg] Yasen Pramatarov <yasen@lindeas.com>",
-"[ca] Carles Tubio Terrón <c@rles-tub.io>",
+"[ca] David Medina <opensusecatala@gmail.com>",
 "[cs] David Vachulka <david@konstrukce-cad.com>",
-"[de] Thomas Bellmann <ThomasBellmann@gmx.net>",
+"[da] Erik P. Olsen <epodata@gmail.com>",
+"[de] Simon Legner <simon.legner@gmail.com>",
 "[en_GB] Paul Mangan <paul@claws-mail.org>",
-"[eo] Sian Mountbatten <poenikatu@fastmail.co.uk>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
-"     Carles Tubio Terrón <c@rles-tub.io>",
 "[fi] Flammie Pirinen <flammie@iki.fi>",
 "[fr] Tristan Chabredier <wwp@claws-mail.org>",
-"[he] Isratine Citizen <genghiskhan@gmx.ca>",
 "[hu] Páder Rezső <rezso@rezso.net>",
-"[id] MSulchan Darmawan <bleketux@gmail.com>",
-"[lt] Mindaugas Baranauskas <embar@super.lt>",
+"[id_ID] MSulchan Darmawan <bleketux@gmail.com>",
+"[it] Luigi Votta <luigi.vtt@gmail.com>",
+"[ja] UTUMI Hirosi <utuhiro78@yahoo.co.jp>",
 "[nb] Petter Adsen <petter@synth.no>",
+"[nl] Marcel Pol <mpol@gmx.net>",
+"[pl] Jakub Jankiewicz <jcubic@jcubic.pl>",
 "[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
+"[ro] Cristian Secară <liste@secarica.ro>",
+"[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
 "[sk] Slavko <slavino@slavino.sk>",
 "[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
+"[tr] Numan Demirdöğen <if.gnu.linux@gmail.com>",
+"[zh_TW] Mark Chang <mark.cyj@gmail.com>",
 NULL
 };
 
@@ -85,17 +89,22 @@ static char *CONTRIBS_LIST[] = {
 "André Filipe de Assunção e Brito",
 "Sergei Astanin",
 "Ruslan N. Balkin",
+"Andy Balaam",
 "Henri Bauer",
+"Didier Barvaux",
 "Fabio Júnior Beneditto",
 "M. Benkmann",
 "Wilbert Berendsen",
-"Didier Barvaux",
 "Sébastien Bigaret",
 "Laurent Bigonville",
 "Jean-Luc Biord",
+"Blatinox",
+"Hanno Boeck",
 "Pavlo Bohmat",
+"Ralf Bormann",
 "H. Merijn Brand",
 "Eugene Brevdo",
+"Olivier Brunel",
 "Sean Buckheister",
 "Anton Butanaev",
 "Henrik Carlqvist",
@@ -138,11 +147,13 @@ static char *CONTRIBS_LIST[] = {
 "Stavros Giannouris",
 "Thomas Gilgin",
 "Marius Glauser",
+"Michael Gmelin",
 "Thierry Godefroy",
 "Alex Gorbachenko",
 "Michał Górny",
 "Bodo Graumann",
 "Yang Guilong",
+"Ashish Gupta",
 "Daniel Gustafson",
 "HIROSHIMA",
 "Oliver Haertel",
@@ -153,6 +164,7 @@ static char *CONTRIBS_LIST[] = {
 "Federico Heinz",
 "Geir Helland",
 "Jorge Van Hemelryck",
+"Olaf Hering",
 "Christian Hesse",
 "Higuchi",
 "Hiramatu",
@@ -160,6 +172,9 @@ static char *CONTRIBS_LIST[] = {
 "Michihide Hotta",
 "Shawn Houston",
 "Michael Hughes",
+"Richard Hughes",
+"Arthur Huillet",
+"Ben Hutchings",
 "Chideok Hwang",
 "John E.P. Hynes",
 "Hironori IWANE",
@@ -169,6 +184,7 @@ static char *CONTRIBS_LIST[] = {
 "Mathias Intemann",
 "Ishihara",
 "Jens Jahnke",
+"Daniel Jakots",
 "Pascal Jermini",
 "KAJIWARA",
 "KUROSAWA",
@@ -179,9 +195,11 @@ static char *CONTRIBS_LIST[] = {
 "Fabian Keil",
 "Martin Kluge",
 "IWAMOTO Kouichi",
+"Mikhail Kurinnoi",
 "Abhay S. Kushwaha",
 "Joshua M. Kwan",
 "Jean-Yves Lefort",
+"Flavio Leitner",
 "Jérôme Lelong",
 "Eric Limpens",
 "Thomas Link",
@@ -192,6 +210,7 @@ static char *CONTRIBS_LIST[] = {
 "Jindrich Makovicka",
 "Igor Mammedov",
 "Tim Mann",
+"Darac Marjal",
 "HIRAMATSU Masami",
 "Yasuzaki Masayoshi",
 "Jason McCarver",
@@ -226,6 +245,8 @@ static char *CONTRIBS_LIST[] = {
 "Miquel Oliete",
 "Paul Ollis",
 "Fredrik Olofssen",
+"Orbea",
+"Thomas Orgis",
 "Reza Pakdel",
 "Richard Palo",
 "Marcel Pol",
@@ -280,6 +301,7 @@ static char *CONTRIBS_LIST[] = {
 "Petr Vanek",
 "Jeroen Versteeg",
 "Kevin Vigor",
+"Michael Vilain",
 "Johan Vromans",
 "Botalov Vyacheslav",
 "Radek Vybiral",
