@@ -1348,7 +1348,7 @@ static void add_word_to_personal_cb(GtkWidget *w, gpointer data)
 {
    	GtkAspell *gtkaspell = (GtkAspell *) data; 
 
-	enchant_dict_add_to_pwl(gtkaspell->gtkaspeller->speller, gtkaspell->theword, strlen(gtkaspell->theword));
+	enchant_dict_add(gtkaspell->gtkaspeller->speller, gtkaspell->theword, strlen(gtkaspell->theword));
 
 	gtkaspell->ctx.check_word(gtkaspell->ctx.data);
 	gtkaspell_dict_changed(gtkaspell);
@@ -1797,12 +1797,6 @@ static GtkWidget *make_dictionary_list_submenu(GtkAspell *gtkaspell)
 	menu = gtk_menu_new();
 	curmenu = menu;
 
-	item = gtk_menu_item_new_with_label(_("Change to..."));
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
-
-	item = gtk_separator_menu_item_new();
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
-
 	for (tmp = gtkaspellcheckers->dictionary_list; tmp != NULL; 
 			tmp = g_slist_next(tmp)) {
 		if (count == MENUCOUNT) {
