@@ -1451,7 +1451,7 @@ gtk_sctree_link (GtkCMCTree     *ctree,
 
 			list_end->next = work->next;
 			if (work->next)
-				list = work->next->prev = list_end;
+				work->next->prev = list_end;
 			work->next = (GList *)node;
 			list = (GList *)node;
 			list->prev = work;
