@@ -864,6 +864,7 @@ void gtkut_set_widget_bgcolor_rgb(GtkWidget *widget, guint rgbvalue)
 	newstyle->bg[GTK_STATE_PRELIGHT] = gdk_color;
 	newstyle->bg[GTK_STATE_ACTIVE]   = gdk_color;
 	gtk_widget_set_style(widget, newstyle);
+	gtk_style_unref(newstyle);
 }
   
 /*!
@@ -1254,6 +1255,7 @@ GtkWidget *gtkut_get_link_btn(GtkWidget *window, const gchar *url, const gchar *
 		style->fg[GTK_STATE_ACTIVE]   = uri_color[1];
 		style->fg[GTK_STATE_PRELIGHT] = uri_color[0];
 		gtk_widget_set_style(btn_label, style);
+		gtk_style_unref(style);
 #if !GTK_CHECK_VERSION(3, 0, 0)
 	} else
 		g_warning("color allocation failed");
@@ -1879,6 +1881,8 @@ GdkPixbuf *claws_load_pixbuf_fitting(GdkPixbuf *src_pixbuf, int box_width,
 #if (defined USE_GNUTLS && GLIB_CHECK_VERSION(2,22,0))
 static void auto_configure_done(const gchar *hostname, gint port, gboolean ssl, AutoConfigureData *data)
 {
+	gboolean smtp = strcmp(data->tls_service, "submission") == 0 ? TRUE : FALSE;
+
 	if (hostname != NULL) {
 		if (data->hostname_entry)
 			gtk_entry_set_text(data->hostname_entry, hostname);
@@ -1904,7 +1908,15 @@ static void auto_configure_done(const gchar *hostname, gint port, gboolean ssl,
 				/* Wizard where TLS is [x]SSL + [x]TLS */
 				gtk_toggle_button_set_active(data->ssl_checkbtn, TRUE);
 			}
-			gtk_toggle_button_set_active(data->tls_checkbtn, TRUE);
+
+			/* Even though technically this is against the RFCs,
+			 * if a "_submission._tcp" SRV record uses port 465,
+			 * it is safe to assume TLS-only service, instead of
+			 * plaintext + STARTTLS one. */
+			if (smtp && port == 465)
+				gtk_toggle_button_set_active(data->ssl_checkbtn, TRUE);
+			else
+				gtk_toggle_button_set_active(data->tls_checkbtn, TRUE);
 		}
 
 		/* Check authentication by default. This is probably required if
