@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2016 Michael Rasmussen and the Claws Mail Team
+ * Copyright (C) 1999-2017 Michael Rasmussen and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -460,7 +460,7 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 	debug_print("File: %s\n", archive_name);
 	arch = archive_write_new();
 	switch (method) {
-		case ZIP:
+		case GZIP:
 #if ARCHIVE_VERSION_NUMBER < 3000000
 			if (archive_write_set_compression_gzip(arch) != ARCHIVE_OK)
 #else
@@ -484,6 +484,50 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 #endif
     			        return archive_error_string(arch);
 			break;
+#if ARCHIVE_VERSION_NUMBER >= 2006990
+		case LZMA:
+#if ARCHIVE_VERSION_NUMBER < 3000000
+			if (archive_write_set_compression_lzma(arch) != ARCHIVE_OK)
+#else
+			if (archive_write_add_filter_lzma(arch) != ARCHIVE_OK)
+#endif
+				return archive_error_string(arch);
+			break;
+		case XZ:
+#if ARCHIVE_VERSION_NUMBER < 3000000
+			if (archive_write_set_compression_xz(arch) != ARCHIVE_OK)
+#else
+			if (archive_write_add_filter_xz(arch) != ARCHIVE_OK)
+#endif
+				return archive_error_string(arch);
+			break;
+#endif
+#if ARCHIVE_VERSION_NUMBER >= 3000000
+		case LZIP:
+			if (archive_write_add_filter_lzip(arch) != ARCHIVE_OK)
+				return archive_error_string(arch);
+			break;
+#endif
+#if ARCHIVE_VERSION_NUMBER >= 3001000
+		case LRZIP:
+			if (archive_write_add_filter_lrzip(arch) != ARCHIVE_OK)
+				return archive_error_string(arch);
+			break;
+		case LZOP:
+			if (archive_write_add_filter_lzop(arch) != ARCHIVE_OK)
+				return archive_error_string(arch);
+			break;
+		case GRZIP:
+			if (archive_write_add_filter_grzip(arch) != ARCHIVE_OK)
+				return archive_error_string(arch);
+			break;
+#endif
+#if ARCHIVE_VERSION_NUMBER >= 3001900
+		case LZ4:
+			if (archive_write_add_filter_lz4(arch) != ARCHIVE_OK)
+				return archive_error_string(arch);
+			break;
+#endif
 		case NO_COMPRESS:
 #if ARCHIVE_VERSION_NUMBER < 3000000
 			if (archive_write_set_compression_none(arch) != ARCHIVE_OK)
@@ -544,37 +588,40 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 #endif
 			entry = archive_entry_new();
 			if ((fd = open(filename, O_RDONLY)) == -1) {
-				perror("open file");
+				FILE_OP_ERROR(filename, "open");
 			}
 			else {
-				lstat(filename, &st);
-				archive_entry_copy_stat(entry, &st);
-				archive_entry_set_pathname(entry, filename);
-				if (S_ISLNK(st.st_mode)) {
-					buf = NULL;
-					buf = malloc(PATH_MAX + 1);
-					if ((len = readlink(filename, buf, PATH_MAX)) < 0)
-						perror("error in readlink");
-					else
-						buf[len] = '\0';
-					archive_entry_set_symlink(entry, buf);
-					g_free(buf);
-					archive_entry_set_size(entry, 0);
-					archive_write_header(arch, entry);
-				}
-				else {
-					if (archive_write_header(arch, entry) != ARCHIVE_OK)
-						g_warning("%s", archive_error_string(arch));
-					buf = NULL;
-					buf = malloc(READ_BLOCK_SIZE);
-					len = read(fd, buf, READ_BLOCK_SIZE);
-					while (len > 0) {
-						if (archive_write_data(arch, buf, len) == -1)
+				if (lstat(filename, &st) == -1) {
+					FILE_OP_ERROR(filename, "lstat");
+				} else {
+					archive_entry_copy_stat(entry, &st);
+					archive_entry_set_pathname(entry, filename);
+					if (S_ISLNK(st.st_mode)) {
+						if ((buf = malloc(PATH_MAX + 1)) != NULL) {
+							if ((len = readlink(filename, buf, PATH_MAX)) < 0) {
+								FILE_OP_ERROR(filename, "readlink");
+							} else
+								buf[len] = '\0';
+							archive_entry_set_symlink(entry, buf);
+							g_free(buf);
+							archive_entry_set_size(entry, 0);
+							archive_write_header(arch, entry);
+						}
+					}
+					else {
+						if (archive_write_header(arch, entry) != ARCHIVE_OK)
 							g_warning("%s", archive_error_string(arch));
-						memset(buf, 0, READ_BLOCK_SIZE);
-						len = read(fd, buf, READ_BLOCK_SIZE);
+						if ((buf = malloc(READ_BLOCK_SIZE)) != NULL) {
+							len = read(fd, buf, READ_BLOCK_SIZE);
+							while (len > 0) {
+								if (archive_write_data(arch, buf, len) == -1)
+									g_warning("%s", archive_error_string(arch));
+								memset(buf, 0, READ_BLOCK_SIZE);
+								len = read(fd, buf, READ_BLOCK_SIZE);
+							}
+							g_free(buf);
+						}
 					}
-					g_free(buf);
 				}
 				close(fd);
 				archive_entry_free(entry);
@@ -700,3 +747,8 @@ int main(int argc, char** argv) {
 	return EXIT_SUCCESS;
 }
 #endif
+
+void archiver_set_tooltip(GtkWidget* widget, gchar* text) {
+    gtk_widget_set_tooltip_text(widget, text);
+    g_free(text);
+}
