@@ -33,6 +33,8 @@
 #include <webkit/webkitversion.h>
 #include <webkit/webkitwebframe.h>
 #include <webkit/webkitnetworkrequest.h>
+#include <webkit/webkitwebnavigationaction.h>
+#include <webkit/webkitwebpolicydecision.h>
 #if WEBKIT_CHECK_VERSION (1,3,10)
 #include <webkit/webkitglobals.h>
 #endif
@@ -116,6 +118,10 @@ struct _FancyViewer
 	gulong            doc_handle;
 	gint              loading;
 
+	/* Coordinates of the last mouse click. */
+	gint              click_x;
+	gint              click_y;
+
 	/* DOM Objects */
 #if WEBKIT_CHECK_VERSION(1,5,1)
 	WebKitDOMDocument	  *doc;
