@@ -30,6 +30,7 @@
 #include "libravatar.h"
 #include "libravatar_prefs.h"
 #include "libravatar_cache.h"
+#include "libravatar_image.h"
 #include "libravatar_missing.h"
 #include "libravatar_federation.h"
 #include "prefs_common.h"
@@ -96,9 +97,21 @@ default_url:
 	return g_strdup(libravatarprefs.base_url);
 }
 
-static GtkWidget *image_widget_from_filename(const gchar *filename)
+static GtkWidget *image_widget_from_pixbuf(GdkPixbuf *picture)
 {
 	GtkWidget *image = NULL;
+
+	if (picture) {
+		image = gtk_image_new_from_pixbuf(picture);
+		g_object_unref(picture);
+	} else
+		g_warning("null picture returns null widget");
+
+	return image;
+}
+
+static GtkWidget *image_widget_from_filename(const gchar *filename)
+{
 	GdkPixbuf *picture = NULL;
 	GError *error = NULL;
 	gint w, h;
@@ -115,15 +128,10 @@ static GtkWidget *image_widget_from_filename(const gchar *filename)
 	if (error != NULL) {
 		g_warning("failed to load image '%s': %s", filename, error->message);
 		g_error_free(error);
-	} else {
-		if (picture) {
-			image = gtk_image_new_from_pixbuf(picture);
-			g_object_unref(picture);
-		} else
-			g_warning("failed to load image '%s': no error returned!", filename);
+		return NULL;
 	}
 
-	return image;
+	return image_widget_from_pixbuf(picture);
 }
 
 static gchar *cache_name_for_md5(const gchar *md5)
@@ -149,61 +157,17 @@ static size_t write_image_data_cb(void *ptr, size_t size, size_t nmemb, void *st
 static GtkWidget *image_widget_from_url(const gchar *url, const gchar *md5)
 {
 	GtkWidget *image = NULL;
-	gchar *filename;
-	FILE *file;
-	CURL *curl;
+	AvatarImageFetch aif;
 
-	curl = curl_easy_init();
-	if (curl == NULL) {
-		g_warning("could not initialize curl to get image from URL");
-		return NULL;
+	aif.url = url;
+	aif.md5 = md5;
+	aif.filename = cache_name_for_md5(md5);
+	libravatar_image_fetch(&aif);
+	if (aif.pixbuf) {
+		image = gtk_image_new_from_pixbuf(aif.pixbuf);
+		g_object_unref(aif.pixbuf);
 	}
-	curl_easy_setopt(curl, CURLOPT_URL, url);
-	curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_image_data_cb);
-	/* make sure timeout is less than general IO timeout */
-	curl_easy_setopt(curl, CURLOPT_TIMEOUT,
-			(libravatarprefs.timeout == 0
-				|| libravatarprefs.timeout
-					> prefs_common_get_prefs()->io_timeout_secs)
-			? prefs_common_get_prefs()->io_timeout_secs
-			: libravatarprefs.timeout);
-	curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 1);
-
-	filename = cache_name_for_md5(md5);
-	file = fopen(filename, "wb");
-	if (file != NULL) {
-		long filesize;
-
-		if (libravatarprefs.allow_redirects) {
-			long maxredirs = (libravatarprefs.default_mode == DEF_MODE_URL)? 3L
-				: ((libravatarprefs.default_mode == DEF_MODE_MM)? 2L: 1L);
-
-			curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1L);
-			curl_easy_setopt(curl, CURLOPT_MAXREDIRS, maxredirs);
-		}
-		curl_easy_setopt(curl, CURLOPT_FILE, file);
-		debug_print("retrieving URL to file: %s -> %s\n", url, filename);
-		curl_easy_perform(curl);
-		filesize = ftell(file);
-    		fclose(file);
-
-		if (filesize < MIN_PNG_SIZE)
-			debug_print("not enough data for an avatar image: %ld bytes\n", filesize);
-		else
-			image = image_widget_from_filename(filename);
-
-		if (!libravatarprefs.cache_icons || filesize == 0) {
-			if (g_unlink(filename) < 0)
-				g_warning("failed to delete cache file '%s'", filename);
-		}
-
-		if (filesize == 0)
-			missing_add_md5(libravatarmisses, md5);
-	} else {
-		g_warning("could not open '%s' for writing", filename);
-	}
-	curl_easy_cleanup(curl);
-	g_free(filename);
+	g_free(aif.filename);
 
 	return image;
 }
