@@ -469,6 +469,8 @@ static void notification_trayicon_on_popup_menu(GtkStatusIcon *status_icon,
 	cm_toggle_menu_set_active("SysTrayiconPopup/ShowBubbles", notify_config.trayicon_popup_enabled);
 #endif
 	cm_menu_set_sensitive("SysTrayiconPopup/GetMail", mainwin->lock_count == 0);
+	cm_menu_set_sensitive("SysTrayiconPopup/GetMailAcc", mainwin->lock_count == 0);
+	cm_menu_set_sensitive("SysTrayiconPopup/Exit", mainwin->lock_count == 0);
 
   updating_menu = FALSE;
 
@@ -921,7 +923,7 @@ static gchar* notification_trayicon_popup_assemble_body(MsgInfo *msginfo)
 		      		     "%d new mail messages arrived",
 		            popup.num_mail),
 			    popup.num_mail);
-      tmp = g_strdup_printf("%s%s%s",utf8_str,str_empty?"":"\n",msg);
+      tmp = g_strdup_printf("%s%s%s",utf8_str,"",msg);
       g_free(msg);
       g_free(utf8_str);
       utf8_str = tmp;
